package net.za.darkskies.wildfire.plugin;

import org.jivesoftware.wildfire.container.Plugin;
import org.jivesoftware.wildfire.container.PluginManager;

import org.jivesoftware.util.Log;
import org.jivesoftware.util.JiveGlobals;
import org.jivesoftware.wildfire.net.SASLAuthentication;

import java.io.File;
import java.util.*;

public class SASLMechanismsPlugin implements Plugin
{
    public void initializePlugin(PluginManager manager, File pluginDirectory)
    {
        Set<String> current = SASLAuthentication.getSupportedMechanisms();
        String available = JiveGlobals.getXMLProperty("sasl.mechs");
        if (available != null)
        {
            StringTokenizer st = new StringTokenizer(available, " ,\t\n\r\f");
            while (st.hasMoreTokens())
            {
                String mech = st.nextToken();
                if (!current.contains(mech))
                {
                    Log.debug("SASLMechanismsPlugin: Added " + mech + " to mech list");
                    SASLAuthentication.addSupportedMechanism(mech);
                }
            }
        }
    }

    public void destroyPlugin()
    {
        Set<String> current = SASLAuthentication.getSupportedMechanisms();
        current = new HashSet<String>(current);
        for (String mech : current)
        {
            if (!(mech.equals("ANONYMOUS") ||
                mech.equals("PLAIN") ||
                mech.equals("DIGEST-MD5") ||
                mech.equals("CRAM-MD5") ||
                mech.equals("GSSAPI")))
            {
                Log.debug("SASLMechanismsPlugin: Removed " + mech + " from mech list");
                SASLAuthentication.removeSupportedMechanism(mech);
            }
        }

        if (current.contains("GSSAPI")) {
            if ((JiveGlobals.getXMLProperty("sasl.mechs") == null) || 
                (JiveGlobals.getXMLProperty("sasl.gssapi.config") == null)) {
                //Not configured, remove the option.
                Log.debug("SASLMechanismsPlugin: Removed GSSAPI from mech list");
                SASLAuthentication.removeSupportedMechanism("GSSAPI");
            }
        }
    }
}
